{% extends "layout.html" %}
{% block body %}
Welcome!<br>

This is SlapOS buildout web based runner.

SlapOS runner is web based development tool which uses slapgrid to install and instantiate the software.
{% endblock %}
